@@ -5,12 +5,15 @@ use serde::{Deserialize, Serialize};
 pub use checkout_server_derive::Server;
 
 use crate::context::{Context, ContextProvider};
+use crate::customer::{Address, Contact};
 use crate::error::Error;
 use crate::money::Currency;
 
 #[derive(Serialize, Deserialize, JsonSchema)]
 pub struct CreateRequest {
     pub currency: Currency,
+    pub contact: Option<Contact>,
+    pub shipping_address: Option<Address>,
 }
 
 pub trait Server<'a, T: Context>: ContextProvider<'a, T> {
